@@ -5,8 +5,7 @@ from pathlib import Path
 import joblib
 
 from bella_companion.simulations.scenarios import SCENARIOS
-from bella_companion.utils import summarize_logs as _summarize_logs
-from bella_companion.utils import summarize_weights
+from bella_companion.utils import read_weights_dir, summarize_logs_dir
 
 
 def summarize_logs():
@@ -20,12 +19,12 @@ def summarize_logs():
         for model in job_ids[scenario_name]:
             logs_dir = output_dir / scenario_name / model
             print(f"Summarizing {scenario_name} - {model}")
-            summary = _summarize_logs(
+            summary = summarize_logs_dir(
                 logs_dir,
                 target_columns=[c for t in scenario.targets.values() for c in t],
                 job_ids=job_ids[scenario_name][model],
             )
             summary.write_csv(summaries_dir / f"{model}.csv")
             if model.startswith("MLP"):
-                weights = summarize_weights(logs_dir)
+                weights = read_weights_dir(logs_dir)
                 joblib.dump(weights, summaries_dir / f"{model}.weights.pkl")
